==> Jetson_Multimedia_API_R32.4.4_aarch64.tbz2: usr/src/jetson_multimedia_api/argus/docs/doxygen/html/search/functions_73.js <==
var searchData=
[
  ['setaeantibandingmode',['setAeAntibandingMode',['../classArgus_1_1IAutoControlSettings.html#a1ee11801c9eb5281c6b551d1bde23f60',1,'Argus::IAutoControlSettings']]],
  ['setaelock',['setAeLock',['../classArgus_1_1IAutoControlSettings.html#aeb0065ad73870e6dde05606e78088551',1,'Argus::IAutoControlSettings']]],
  ['setaeregions',['setAeRegions',['../classArgus_1_1IAutoControlSettings.html#ae8b956909eff7e17a9a3a53a9f2f605c',1,'Argus::IAutoControlSettings']]],
  ['setaperturemotorspeed',['setApertureMotorSpeed',['../classArgus_1_1ISourceSettings.html#ae0e3645fe7f7dc0ca1516d2ec4a830a7',1,'Argus::ISourceSettings']]],
  ['setaperturemotorstep',['setApertureMotorStep',['../classArgus_1_1ISourceSettings.html#a530ec44d54e90440533180dc39ec596b',1,'Argus::ISourceSettings']]],
  ['setawblock',['setAwbLock',['../classArgus_1_1IAutoControlSettings.html#ac14f7bf31f315c4f0f148aa17a30b312',1,'Argus::IAutoControlSettings']]],
  ['setawbmode',['setAwbMode',['../classArgus_1_1IAutoControlSettings.html#a37d259ea62879c41c89e993e137e487d',1,'Argus::IAutoControlSettings']]],
  ['setawbregions',['setAwbRegions',['../classArgus_1_1IAutoControlSettings.html#a487f7454abb8efddcbc90545ab7aaaaa',1,'Argus::IAutoControlSettings']]],
  ['setbayeraveragemapenable',['setBayerAverageMapEnable',['../classArgus_1_1Ext_1_1IBayerAverageMapSettings.html#a3123de1b0c0011223da00a9fb912be9d',1,'Argus::Ext::IBayerAverageMapSettings']]],
  ['setbayersharpnessmapenable',['setBayerSharpnessMapEnable',['../classArgus_1_1Ext_1_1IBayerSharpnessMapSettings.html#a0eeeb789780fafa47d743bfedf6b3c29',1,'Argus::Ext::IBayerSharpnessMapSettings']]],
  ['setbuffertype',['setBufferType',['../classArgus_1_1IBufferOutputStreamSettings.html#a044d6eed4ef067f601d2aa433d679e72',1,'Argus::IBufferOutputStreamSettings']]],
  ['setcameradevice',['setCameraDevice',['../classArgus_1_1IOutputStreamSettings.html#ad746419d46b3e955525abdf2885419c5',1,'Argus::IOutputStreamSettings']]],
  ['setclientdata',['setClientData',['../classArgus_1_1IBuffer.html#acb514fb8f0d6b2651a9fb82736143aa2',1,'Argus::IBuffer::setClientData()'],['../classArgus_1_1IRequest.html#a55e55ea823ad98f286f2505c067458ac',1,'Argus::IRequest::setClientData()']]],
  ['setcolorcorrectionmatrix',['setColorCorrectionMatrix',['../classArgus_1_1IAutoControlSettings.html#a24001773f7a288aaa97b13f8181f5456',1,'Argus::IAutoControlSettings']]],
  ['setcolorcorrectionmatrixenable',['setColorCorrectionMatrixEnable',['../classArgus_1_1IAutoControlSettings.html#a4a822eb05bc4398d6c38f1a67fc9883b',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturation',['setColorSaturation',['../classArgus_1_1IAutoControlSettings.html#a0a94a306e28e90b5ca017c77e69c6436',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturationbias',['setColorSaturationBias',['../classArgus_1_1IAutoControlSettings.html#abc4e0e250193be956d444f03767f0178',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturationenable',['setColorSaturationEnable',['../classArgus_1_1IAutoControlSettings.html#a21009b33d8b636293f888752b1747eab',1,'Argus::IAutoControlSettings']]],
  ['setdefogamount',['setDeFogAmount',['../classArgus_1_1Ext_1_1IDeFogSettings.html#ab3540ae030b9b94ad0638c9c2d734790',1,'Argus::Ext::IDeFogSettings']]],
  ['setdefogenable',['setDeFogEnable',['../classArgus_1_1Ext_1_1IDeFogSettings.html#a457195ea6f2e2b40caa52045f6c1f85d',1,'Argus::Ext::IDeFogSettings']]],
  ['setdefogquality',['setDeFogQuality',['../classArgus_1_1Ext_1_1IDeFogSettings.html#afbd75c96d0766ebaff93824b1d4cb68e',1,'Argus::Ext::IDeFogSettings']]],
  ['setdenoisemode',['setDenoiseMode',['../classArgus_1_1IDenoiseSettings.html#af989064021965c35990fe83204d3b849',1,'Argus::IDenoiseSettings']]],
  ['setdenoisestrength',['setDenoiseStrength',['../classArgus_1_1IDenoiseSettings.html#ac9659df2f9f363c73d554befa0b785b1',1,'Argus::IDenoiseSettings']]],
  ['setedgeenhancemode',['setEdgeEnhanceMode',['../classArgus_1_1IEdgeEnhanceSettings.html#a600fc91a9d1695d33533d06c72a67570',1,'Argus::IEdgeEnhanceSettings']]],
  ['setedgeenhancestrength',['setEdgeEnhanceStrength',['../classArgus_1_1IEdgeEnhanceSettings.html#acb561fb70e4b51491a540597b8f050c7',1,'Argus::IEdgeEnhanceSettings']]],
  ['setegldisplay',['setEGLDisplay',['../classArgus_1_1IEGLImageBufferSettings.html#a41372cfe3a53e65d4a08d71e98f455d8',1,'Argus::IEGLImageBufferSettings::setEGLDisplay()'],['../classArgus_1_1IEGLOutputStreamSettings.html#a193ea880e8a8b8c6882281c6c1d06fcc',1,'Argus::IEGLOutputStreamSettings::setEGLDisplay()']]],
  ['seteglimage',['setEGLImage',['../classArgus_1_1IEGLImageBufferSettings.html#aeb95bffdf14662c019605cc2ffd3eafc',1,'Argus::IEGLImageBufferSettings']]],
  ['setexposurecompensation',['setExposureCompensation',['../classArgus_1_1IAutoControlSettings.html#a15dae0f7e79587f29226ec184b50f45d',1,'Argus::IAutoControlSettings']]],
  ['setexposurecount',['setExposureCount',['../classArgus_1_1IEGLOutputStreamSettings.html#a52c74e9f87ed80732824e63ce6d88b1d',1,'Argus::IEGLOutputStreamSettings']]],
  ['setexposuretimerange',['setExposureTimeRange',['../classArgus_1_1ISourceSettings.html#a97259077b42ecfb13d139da5ede8c2a1',1,'Argus::ISourceSettings']]],
  ['setfacedetectenable',['setFaceDetectEnable',['../classArgus_1_1Ext_1_1IFaceDetectSettings.html#ac16b0edce8d1b9d3c088aa3291c67227',1,'Argus::Ext::IFaceDetectSettings']]],
  ['setfifolength',['setFifoLength',['../classArgus_1_1IEGLOutputStreamSettings.html#a73da480070bfed70ccc90af38e67972f',1,'Argus::IEGLOutputStreamSettings']]],
  ['setfocusposition',['setFocusPosition',['../classArgus_1_1ISourceSettings.html#acb57376b76666a116ba68c14b3856c3e',1,'Argus::ISourceSettings']]],
  ['setframedurationrange',['setFrameDurationRange',['../classArgus_1_1ISourceSettings.html#a46f05e2816befd695fd3ae68d856cf96',1,'Argus::ISourceSettings']]],
  ['setgainrange',['setGainRange',['../classArgus_1_1ISourceSettings.html#a9cdfb914b0e1da3a2f9fe4143f9c8e57',1,'Argus::ISourceSettings']]],
  ['setispdigitalgainrange',['setIspDigitalGainRange',['../classArgus_1_1IAutoControlSettings.html#ad2504986fcddc78fff56674c00c0d989',1,'Argus::IAutoControlSettings']]],
  ['setmetadataenable',['setMetadataEnable',['../classArgus_1_1IBufferOutputStreamSettings.html#ac8936d0dab592d0bdbbe74adee2deb78',1,'Argus::IBufferOutputStreamSettings::setMetadataEnable()'],['../classArgus_1_1IEGLOutputStreamSettings.html#a940c087cb046b2cf0e7ec1274ed9551a',1,'Argus::IEGLOutputStreamSettings::setMetadataEnable()'],['../classArgus_1_1Ext_1_1ISensorPrivateMetadataRequest.html#a3eec7c6b9d5cbe48399c8c658e0467c8',1,'Argus::Ext::ISensorPrivateMetadataRequest::setMetadataEnable()']]],
  ['setmode',['setMode',['../classArgus_1_1IEGLOutputStreamSettings.html#a81ba6a662080f07809fb717b3a7e586f',1,'Argus::IEGLOutputStreamSettings']]],
  ['setopticalblack',['setOpticalBlack',['../classArgus_1_1ISourceSettings.html#a38cfe2647989ff1bba4bba979977c487',1,'Argus::ISourceSettings']]],
  ['setopticalblackenable',['setOpticalBlackEnable',['../classArgus_1_1ISourceSettings.html#a5ede1e4f4e44267ae1abc8eb758674fd',1,'Argus::ISourceSettings']]],
  ['setpixelformat',['setPixelFormat',['../classArgus_1_1IEGLOutputStreamSettings.html#ae2354bf23b8fb0fd0d7df9057d016e59',1,'Argus::IEGLOutputStreamSettings']]],
  ['setpostprocessingenable',['setPostProcessingEnable',['../classArgus_1_1IStreamSettings.html#aab91aa8fe6d07ab356d43bcc7712f2a0',1,'Argus::IStreamSettings']]],
  ['setreleasesync',['setReleaseSync',['../classArgus_1_1IEGLSync.html#a21f3f31f4869ec8a35cce274e5b23943',1,'Argus::IEGLSync']]],
  ['setresolution',['setResolution',['../classArgus_1_1IEGLOutputStreamSettings.html#a0cfb60bb7d22b1f52a6c57ea840cf0d0',1,'Argus::IEGLOutputStreamSettings']]],
  ['setsensormode',['setSensorMode',['../classArgus_1_1ISourceSettings.html#a50b962954ae6fcc9d024999390383071',1,'Argus::ISourceSettings']]],
  ['setsourcecliprect',['setSourceClipRect',['../classArgus_1_1IStreamSettings.html#afed99500f424659edacb8a55310311d2',1,'Argus::IStreamSettings']]],
  ['setsynctype',['setSyncType',['../classArgus_1_1IBufferOutputStreamSettings.html#afac7de8fd641eccb142ebd8c2c070258',1,'Argus::IBufferOutputStreamSettings']]],
  ['settonemapcurve',['setToneMapCurve',['../classArgus_1_1IAutoControlSettings.html#ad4467e28d8f8cdec4a0069a6e2dfb2af',1,'Argus::IAutoControlSettings']]],
  ['settonemapcurveenable',['setToneMapCurveEnable',['../classArgus_1_1IAutoControlSettings.html#a054d1626fcf4a159fa41e87efbfac1ee',1,'Argus::IAutoControlSettings']]],
  ['setwbgains',['setWbGains',['../classArgus_1_1IAutoControlSettings.html#ab224517cee96b01c666c0a774ac533da',1,'Argus::IAutoControlSettings']]],
  ['size',['size',['../classArgus_1_1Array2D.html#ab2cc11837aaf23d1ea9c7e361438b592',1,'Argus::Array2D']]],
  ['size2d',['Size2D',['../classArgus_1_1Size2D.html#a030cea1165690b1120f27eb8e42327a5',1,'Argus::Size2D::Size2D()'],['../classArgus_1_1Size2D.html#ac2715348690a4bae9170e4294915b25e',1,'Argus::Size2D::Size2D(const Tuple&lt; 2, T &gt; &amp;other)'],['../classArgus_1_1Size2D.html#ad6f5fab4c4b6686f4b97ab968ccd85d4',1,'Argus::Size2D::Size2D(T init)'],['../classArgus_1_1Size2D.html#a15d00d033095f2da873e92f1b346a812',1,'Argus::Size2D::Size2D(T _width, T _height)']]],
  ['stoprepeat',['stopRepeat',['../classArgus_1_1ICaptureSession.html#a49df8458b54d58fd5538c982565acd0e',1,'Argus::ICaptureSession']]],
  ['supportsextension',['supportsExtension',['../classArgus_1_1ICameraProvider.html#acb729080a0071b42f9d4f801b18a17ca',1,'Argus::ICameraProvider']]],
  ['supportsoutputstreamformat',['supportsOutputStreamFormat',['../classArgus_1_1IEGLOutputStreamSettings.html#a9f57d8b140a1fb8321e6022871d59402',1,'Argus::IEGLOutputStreamSettings']]]
];

==> Jetson_Multimedia_API_R32.5.0_aarch64.tbz2: usr/src/jetson_multimedia_api/argus/docs/doxygen/html/search/functions_73.js <==
var searchData=
[
  ['setaeantibandingmode',['setAeAntibandingMode',['../classArgus_1_1IAutoControlSettings.html#a1ee11801c9eb5281c6b551d1bde23f60',1,'Argus::IAutoControlSettings']]],
  ['setaelock',['setAeLock',['../classArgus_1_1IAutoControlSettings.html#aeb0065ad73870e6dde05606e78088551',1,'Argus::IAutoControlSettings']]],
  ['setaeregions',['setAeRegions',['../classArgus_1_1IAutoControlSettings.html#ae8b956909eff7e17a9a3a53a9f2f605c',1,'Argus::IAutoControlSettings']]],
  ['setafregions',['setAfRegions',['../classArgus_1_1IAutoControlSettings.html#a76313a4e697a4f14c5d4912bf9944dff',1,'Argus::IAutoControlSettings']]],
  ['setaperturefnumber',['setApertureFNumber',['../classArgus_1_1ISourceSettings.html#a5d1f6178d717423a951c82728e342495',1,'Argus::ISourceSettings']]],
  ['setaperturemotorspeed',['setApertureMotorSpeed',['../classArgus_1_1ISourceSettings.html#ae0e3645fe7f7dc0ca1516d2ec4a830a7',1,'Argus::ISourceSettings']]],
  ['setapertureposition',['setAperturePosition',['../classArgus_1_1ISourceSettings.html#aeae3265fd9d105098ee498461aba97bc',1,'Argus::ISourceSettings']]],
  ['setawblock',['setAwbLock',['../classArgus_1_1IAutoControlSettings.html#ac14f7bf31f315c4f0f148aa17a30b312',1,'Argus::IAutoControlSettings']]],
  ['setawbmode',['setAwbMode',['../classArgus_1_1IAutoControlSettings.html#a37d259ea62879c41c89e993e137e487d',1,'Argus::IAutoControlSettings']]],
  ['setawbregions',['setAwbRegions',['../classArgus_1_1IAutoControlSettings.html#a487f7454abb8efddcbc90545ab7aaaaa',1,'Argus::IAutoControlSettings']]],
  ['setbayeraveragemapenable',['setBayerAverageMapEnable',['../classArgus_1_1Ext_1_1IBayerAverageMapSettings.html#a3123de1b0c0011223da00a9fb912be9d',1,'Argus::Ext::IBayerAverageMapSettings']]],
  ['setbayerhistogramregion',['setBayerHistogramRegion',['../classArgus_1_1IAutoControlSettings.html#ab4069e77b2fb5b8b2a254a36c980ca85',1,'Argus::IAutoControlSettings']]],
  ['setbayersharpnessmapenable',['setBayerSharpnessMapEnable',['../classArgus_1_1Ext_1_1IBayerSharpnessMapSettings.html#a0eeeb789780fafa47d743bfedf6b3c29',1,'Argus::Ext::IBayerSharpnessMapSettings']]],
  ['setbuffertype',['setBufferType',['../classArgus_1_1IBufferOutputStreamSettings.html#a044d6eed4ef067f601d2aa433d679e72',1,'Argus::IBufferOutputStreamSettings']]],
  ['setcameradevice',['setCameraDevice',['../classArgus_1_1IOutputStreamSettings.html#ad746419d46b3e955525abdf2885419c5',1,'Argus::IOutputStreamSettings']]],
  ['setclientdata',['setClientData',['../classArgus_1_1IBuffer.html#acb514fb8f0d6b2651a9fb82736143aa2',1,'Argus::IBuffer::setClientData()'],['../classArgus_1_1IRequest.html#a55e55ea823ad98f286f2505c067458ac',1,'Argus::IRequest::setClientData()']]],
  ['setclientmetadatabuffer',['setClientMetadataBuffer',['../classArgus_1_1Ext_1_1ISensorPrivateMetadataClientBufferRequest.html#a7f6178e6ed6678c614cf2d4407657b37',1,'Argus::Ext::ISensorPrivateMetadataClientBufferRequest']]],
  ['setcolorcorrectionmatrix',['setColorCorrectionMatrix',['../classArgus_1_1IAutoControlSettings.html#a24001773f7a288aaa97b13f8181f5456',1,'Argus::IAutoControlSettings']]],
  ['setcolorcorrectionmatrixenable',['setColorCorrectionMatrixEnable',['../classArgus_1_1IAutoControlSettings.html#a4a822eb05bc4398d6c38f1a67fc9883b',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturation',['setColorSaturation',['../classArgus_1_1IAutoControlSettings.html#a0a94a306e28e90b5ca017c77e69c6436',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturationbias',['setColorSaturationBias',['../classArgus_1_1IAutoControlSettings.html#abc4e0e250193be956d444f03767f0178',1,'Argus::IAutoControlSettings']]],
  ['setcolorsaturationenable',['setColorSaturationEnable',['../classArgus_1_1IAutoControlSettings.html#a21009b33d8b636293f888752b1747eab',1,'Argus::IAutoControlSettings']]],
  ['setdefogamount',['setDeFogAmount',['../classArgus_1_1Ext_1_1IDeFogSettings.html#ab3540ae030b9b94ad0638c9c2d734790',1,'Argus::Ext::IDeFogSettings']]],
  ['setdefogenable',['setDeFogEnable',['../classArgus_1_1Ext_1_1IDeFogSettings.html#a457195ea6f2e2b40caa52045f6c1f85d',1,'Argus::Ext::IDeFogSettings']]],
  ['setdefogquality',['setDeFogQuality',['../classArgus_1_1Ext_1_1IDeFogSettings.html#afbd75c96d0766ebaff93824b1d4cb68e',1,'Argus::Ext::IDeFogSettings']]],
  ['setdenoisemode',['setDenoiseMode',['../classArgus_1_1IDenoiseSettings.html#af989064021965c35990fe83204d3b849',1,'Argus::IDenoiseSettings']]],
  ['setdenoisestrength',['setDenoiseStrength',['../classArgus_1_1IDenoiseSettings.html#ac9659df2f9f363c73d554befa0b785b1',1,'Argus::IDenoiseSettings']]],
  ['setedgeenhancemode',['setEdgeEnhanceMode',['../classArgus_1_1IEdgeEnhanceSettings.html#a600fc91a9d1695d33533d06c72a67570',1,'Argus::IEdgeEnhanceSettings']]],
  ['setedgeenhancestrength',['setEdgeEnhanceStrength',['../classArgus_1_1IEdgeEnhanceSettings.html#acb561fb70e4b51491a540597b8f050c7',1,'Argus::IEdgeEnhanceSettings']]],
  ['setegldisplay',['setEGLDisplay',['../classArgus_1_1IEGLImageBufferSettings.html#a41372cfe3a53e65d4a08d71e98f455d8',1,'Argus::IEGLImageBufferSettings::setEGLDisplay()'],['../classArgus_1_1IEGLOutputStreamSettings.html#a193ea880e8a8b8c6882281c6c1d06fcc',1,'Argus::IEGLOutputStreamSettings::setEGLDisplay()']]],
  ['seteglimage',['setEGLImage',['../classArgus_1_1IEGLImageBufferSettings.html#aeb95bffdf14662c019605cc2ffd3eafc',1,'Argus::IEGLImageBufferSettings']]],
  ['seteventinjectionerrormsg',['setEventInjectionErrorMsg',['../classArgus_1_1Ext_1_1IDebugCaptureSession.html#a809772e51e6525ff82d2e75834c1887e',1,'Argus::Ext::IDebugCaptureSession']]],
  ['setexposurecompensation',['setExposureCompensation',['../classArgus_1_1IAutoControlSettings.html#a15dae0f7e79587f29226ec184b50f45d',1,'Argus::IAutoControlSettings']]],
  ['setexposurecount',['setExposureCount',['../classArgus_1_1IEGLOutputStreamSettings.html#a52c74e9f87ed80732824e63ce6d88b1d',1,'Argus::IEGLOutputStreamSettings']]],
  ['setexposuretimerange',['setExposureTimeRange',['../classArgus_1_1ISourceSettings.html#a97259077b42ecfb13d139da5ede8c2a1',1,'Argus::ISourceSettings']]],
  ['setfacedetectenable',['setFaceDetectEnable',['../classArgus_1_1Ext_1_1IFaceDetectSettings.html#ac16b0edce8d1b9d3c088aa3291c67227',1,'Argus::Ext::IFaceDetectSettings']]],
  ['setfifolength',['setFifoLength',['../classArgus_1_1IEGLOutputStreamSettings.html#a73da480070bfed70ccc90af38e67972f',1,'Argus::IEGLOutputStreamSettings']]],
  ['setfocusposition',['setFocusPosition',['../classArgus_1_1ISourceSettings.html#acb57376b76666a116ba68c14b3856c3e',1,'Argus::ISourceSettings']]],
  ['setframedurationrange',['setFrameDurationRange',['../classArgus_1_1ISourceSettings.html#a46f05e2816befd695fd3ae68d856cf96',1,'Argus::ISourceSettings']]],
  ['setgainrange',['setGainRange',['../classArgus_1_1ISourceSettings.html#a9cdfb914b0e1da3a2f9fe4143f9c8e57',1,'Argus::ISourceSettings']]],
  ['setispdigitalgainrange',['setIspDigitalGainRange',['../classArgus_1_1IAutoControlSettings.html#ad2504986fcddc78fff56674c00c0d989',1,'Argus::IAutoControlSettings']]],
  ['setmetadataenable',['setMetadataEnable',['../classArgus_1_1IBufferOutputStreamSettings.html#ac8936d0dab592d0bdbbe74adee2deb78',1,'Argus::IBufferOutputStreamSettings::setMetadataEnable()'],['../classArgus_1_1IEGLOutputStreamSettings.html#a940c087cb046b2cf0e7ec1274ed9551a',1,'Argus::IEGLOutputStreamSettings::setMetadataEnable()'],['../classArgus_1_1Ext_1_1ISensorPrivateMetadataRequest.html#a3eec7c6b9d5cbe48399c8c658e0467c8',1,'Argus::Ext::ISensorPrivateMetadataRequest::setMetadataEnable()']]],
  ['setmode',['setMode',['../classArgus_1_1IEGLOutputStreamSettings.html#a81ba6a662080f07809fb717b3a7e586f',1,'Argus::IEGLOutputStreamSettings']]],
  ['setopticalblack',['setOpticalBlack',['../classArgus_1_1ISourceSettings.html#a38cfe2647989ff1bba4bba979977c487',1,'Argus::ISourceSettings']]],
  ['setopticalblackenable',['setOpticalBlackEnable',['../classArgus_1_1ISourceSettings.html#a5ede1e4f4e44267ae1abc8eb758674fd',1,'Argus::ISourceSettings']]],
  ['setpixelformat',['setPixelFormat',['../classArgus_1_1IEGLOutputStreamSettings.html#ae2354bf23b8fb0fd0d7df9057d016e59',1,'Argus::IEGLOutputStreamSettings']]],
  ['setpostprocessingenable',['setPostProcessingEnable',['../classArgus_1_1IStreamSettings.html#aab91aa8fe6d07ab356d43bcc7712f2a0',1,'Argus::IStreamSettings']]],
  ['setreleasesync',['setReleaseSync',['../classArgus_1_1IEGLSync.html#a21f3f31f4869ec8a35cce274e5b23943',1,'Argus::IEGLSync']]],
  ['setresolution',['setResolution',['../classArgus_1_1IEGLOutputStreamSettings.html#a0cfb60bb7d22b1f52a6c57ea840cf0d0',1,'Argus::IEGLOutputStreamSettings']]],
  ['setsensormode',['setSensorMode',['../classArgus_1_1ISourceSettings.html#a50b962954ae6fcc9d024999390383071',1,'Argus::ISourceSettings']]],
  ['setsourcecliprect',['setSourceClipRect',['../classArgus_1_1IStreamSettings.html#afed99500f424659edacb8a55310311d2',1,'Argus::IStreamSettings']]],
  ['setsynctype',['setSyncType',['../classArgus_1_1IBufferOutputStreamSettings.html#afac7de8fd641eccb142ebd8c2c070258',1,'Argus::IBufferOutputStreamSettings']]],
  ['settonemapcurve',['setToneMapCurve',['../classArgus_1_1IAutoControlSettings.html#ad4467e28d8f8cdec4a0069a6e2dfb2af',1,'Argus::IAutoControlSettings']]],
  ['settonemapcurveenable',['setToneMapCurveEnable',['../classArgus_1_1IAutoControlSettings.html#a054d1626fcf4a159fa41e87efbfac1ee',1,'Argus::IAutoControlSettings']]],
  ['setwbgains',['setWbGains',['../classArgus_1_1IAutoControlSettings.html#ab224517cee96b01c666c0a774ac533da',1,'Argus::IAutoControlSettings']]],
  ['size',['size',['../classArgus_1_1Array2D.html#ab2cc11837aaf23d1ea9c7e361438b592',1,'Argus::Array2D']]],
  ['size2d',['Size2D',['../classArgus_1_1Size2D.html#a030cea1165690b1120f27eb8e42327a5',1,'Argus::Size2D::Size2D()'],['../classArgus_1_1Size2D.html#ac2715348690a4bae9170e4294915b25e',1,'Argus::Size2D::Size2D(const Tuple&lt; 2, T &gt; &amp;other)'],['../classArgus_1_1Size2D.html#ad6f5fab4c4b6686f4b97ab968ccd85d4',1,'Argus::Size2D::Size2D(T init)'],['../classArgus_1_1Size2D.html#a15d00d033095f2da873e92f1b346a812',1,'Argus::Size2D::Size2D(T _width, T _height)']]],
  ['stoprepeat',['stopRepeat',['../classArgus_1_1ICaptureSession.html#a49df8458b54d58fd5538c982565acd0e',1,'Argus::ICaptureSession']]],
  ['supportsextension',['supportsExtension',['../classArgus_1_1ICameraProvider.html#acb729080a0071b42f9d4f801b18a17ca',1,'Argus::ICameraProvider']]],
  ['supportsoutputstreamformat',['supportsOutputStreamFormat',['../classArgus_1_1IEGLOutputStreamSettings.html#a9f57d8b140a1fb8321e6022871d59402',1,'Argus::IEGLOutputStreamSettings']]]
];
